@@ -7,20 +7,22 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
 package org.eclipse.osgi.tests.security;
 
-import junit.framework.*;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
 
 public class SecurityTestSuite extends TestCase {
 	public static Test suite() {
 		TestSuite suite = new TestSuite("Unit tests for Equinox security");
-		//trust engine tests
+		// trust engine tests
 		suite.addTest(KeyStoreTrustEngineTest.suite());
-		//signed bundle tests - *uses* trust engine
+		// signed bundle tests - *uses* trust engine
 		suite.addTest(SignedBundleTest.suite());
 		suite.addTest(SignedBundleTest.localSuite());
 		suite.addTest(OSGiAPICertificateTest.suite());
